
![Ladybug](http://www.ladybug.tools/assets/img/ladybug.png)

[![Build Status](https://travis-ci.org/ladybug-tools/lbt-ladybug.svg?branch=master)](https://travis-ci.org/ladybug-tools/lbt-ladybug)

[![Python 2.7](https://img.shields.io/badge/python-2.7-green.svg)](https://www.python.org/downloads/release/python-270/) [![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/) [![IronPython](https://img.shields.io/badge/ironpython-2.7-red.svg)](https://github.com/IronLanguages/ironpython2/releases/tag/ipy-2.7.8/)

# lbt-ladybug

Collection of all Ladybug core Python libraries.

Note that this repository and corresponding Python package does not contain any
code and it simply exists to provide a shortcut for installing all of the ladybug
core libraries together.

## Included Ladybug Packages

Running `pip install lbt-ladybug` will result in the installation of the
following Python packages:

* [ladybug-core](https://github.com/ladybug-tools/ladybug)
* [ladybug-geometry](https://github.com/ladybug-tools/ladybug-geometry)
* [ladybug-comfort](https://github.com/ladybug-tools/ladybug-comfort)
